==> nextcloud-13.0.1.tgz: nextcloud/apps/theming/l10n/es_AR.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando vista previa...",
    "Saved" : "Guardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un lugar seguro para todos sus datos",
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "No file uploaded" : "No hay archivos cargados",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "You are already using a custom theme" : "Usted ya se encuentra usando un tema personalizado",
    "Theming" : "Tematizar",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve su instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Name" : "Nombre",
    "Reset to default" : "Restablecer al predeterminado",
    "Web address" : "Dirección web",
    "Web address https://…" : "Dirección web https://...",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotipo",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Login image" : "Imágen de inicio de sesión",
    "Upload new login background" : "Cargar nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "reset to default" : "restaurar a predeterminado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/theming/l10n/es_AR.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando vista previa...",
    "Saved" : "Guardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un lugar seguro para todos sus datos",
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "No file uploaded" : "No hay archivos cargados",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "Theming" : "Tematizar",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve su instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Name" : "Nombre",
    "Reset to default" : "Restablecer al predeterminado",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotipo",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Login image" : "Imágen de inicio de sesión",
    "Upload new login background" : "Cargar nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "You are already using a custom theme" : "Usted ya se encuentra usando un tema personalizado",
    "reset to default" : "restaurar a predeterminado",
    "Web address" : "Dirección web",
    "Web address https://…" : "Dirección web https://..."
},
"nplurals=2; plural=(n != 1);");
